<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

final class Spacer_For_Elementor {
    /**
     * Plugin Version
     *
     * @var string The plugin version.
     */
    const  VERSION = '1.0' ;
    /**
     * Minimum Elementor Version
     *
     * @var string Minimum Elementor version required to run the plugin.
     */
    const  MINIMUM_ELEMENTOR_VERSION = '2.8.0' ;
    /**
     * Minimum PHP Version
     *
     * @var string Minimum PHP version required to run the plugin.
     */
    const  MINIMUM_PHP_VERSION = '7.0' ;
    /**
     * Instance
     *
     * @access private
     * @static
     *
     */
    private static  $_instance = null ;
    /**
     * Instance
     *
     * Ensures only one instance of the class is loaded or can be loaded.
     *
     */
    public static function instance()
    {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }
    
    /**
     * Constructor
     */
    public function __construct()
    {
        add_action( 'init', [ $this, 'i18n' ] );
        add_action( 'plugins_loaded', [ $this, 'init' ] );
    }
    
    /**
     * Load Textdomain
     *
     * Load plugin localization files.
     *
     * Fired by `init` action hook.
     */
    public function i18n()
    {
        load_plugin_textdomain( 'spacer-elementor', false, dirname( dirname( __FILE__ ) ) . '/languages' );
    }
    
    /**
     * Initialize the plugin
     *
     * Load the plugin only after Elementor (and other plugins) are loaded.
     * Checks for basic plugin requirements, if one check fail don't continue,
     * if all check have passed load the files required to run the plugin.
     *
     * Fired by `plugins_loaded` action hook.
     */
    public function init()
    {
        // Plugin Directory URL.
        define( 'SPACER_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
        define( 'SPACER_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
        // Check if Elementor installed and activated.
        
        if ( !did_action( 'elementor/loaded' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
            return;
        }
        
        // Check for required Elementor version.
        
        if ( !version_compare( ELEMENTOR_VERSION, self::MINIMUM_ELEMENTOR_VERSION, '>=' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_minimum_elementor_version' ] );
            return;
        }
        
        // Check for required PHP version.
        
        if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
            add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
            return;
        }
        
        add_action( 'admin_menu', [ $this, 'edp_admin_menu' ], 1000 );
        
        require_once SPACER_PLUGIN_PATH . '/spacer/init.php';
    }
    
    /**
     * Renders the admin menu
     */
    public function edp_admin_menu()
    {
        if ( !current_user_can( 'manage_options' ) ) {
            return;
        }
        add_submenu_page(
            'elementor',
            __( 'Spacer for Elementor', 'spacer-elementor' ),
            __( 'Spacer Addon Elementor', 'spacer-elementor' ),
            'manage_options',
            'spacer_elementor_addon',
            [ $this, 'edp_menu_page' ]
        );
    }
    
    /**
     * Settings Page
     */
    public function edp_menu_page()
    {
        require_once SPACER_PLUGIN_PATH . 'spacer/dev-menu.php';
    }
    
    /**
     * Admin notice
     *
     * Warning when the site doesn't have Elementor installed or activated.
     */
    public function admin_notice_missing_main_plugin()
    {
        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }
        $message = sprintf(
            /* translators: 1: Plugin name 2: Elementor */
            esc_html__( '%1$s requires %2$s to be installed and activated.', 'spacer-elementor' ),
            '<strong>' . esc_html__( 'Spacer for Elementor', 'spacer-elementor' ) . '</strong>',
            '<strong>' . esc_html__( 'Elementor', 'spacer-elementor' ) . '</strong>'
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
        //phpcs:ignore
    }
    
    /**
     * Admin notice
     *
     * Warning when the site doesn't have a minimum required Elementor version.
     */
    public function admin_notice_minimum_elementor_version()
    {
        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }
        $message = sprintf(
            /* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
            esc_html__( '%1$s requires %2$s version %3$s or greater.', 'spacer-elementor' ),
            '<strong>' . esc_html__( 'Spacer for Elementor', 'spacer-elementor' ) . '</strong>',
            '<strong>' . esc_html__( 'Elementor', 'spacer-elementor' ) . '</strong>',
            self::MINIMUM_ELEMENTOR_VERSION
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
        //phpcs:ignore
    }
    
    public static function get_js_suffix()
    {
        if ( defined( 'EDP_DEV' ) && EDP_DEV ) {
            return 'dev';
        }
        return 'min';
    }
    
    /**
     * Admin notice
     *
     * Warning when the site doesn't have a minimum required PHP version.
     */
    public function admin_notice_minimum_php_version()
    {
        if ( isset( $_GET['activate'] ) ) {
            unset( $_GET['activate'] );
        }
        $message = sprintf(
            /* translators: 1: Plugin name 2: PHP 3: Required PHP version */
            esc_html__( '%1$s requires %2$s version %3$s or greater.', 'spacer-elementor' ),
            '<strong>' . esc_html__( 'Spacer for Elementor', 'spacer-elementor' ) . '</strong>',
            '<strong>' . esc_html__( 'PHP', 'spacer-elementor' ) . '</strong>',
            self::MINIMUM_PHP_VERSION
        );
        printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );
        //phpcs:ignore
    }

}
Spacer_For_Elementor::instance();